function [CRB_C_c,CRB_C_p_c,CRB_AB_c,CRB_AB_p_c,K_C,K_C_p,K_AB,K_AB_p]= ...
                                      complex_crb_ccp(CRB_C,CRB_AB,D_AB,...
                                   D_C_AB,CRB_C_p,CRB_AB_p,D_AB_p,D_C_AB_p)
%-------------------------------------------------------------------------%
% [CRB_C,CRB_AB,CRB_AB_p,K_C,K_AB,K_AB_p] =                      ...
%                                 complex_crb_ccp(CRB_C,CRB_AB,D_C,D_AB,...
%                           D_AB_C,CRB_C_p,CRB_AB_p,D_C_p,D_AB_p,D_AB_C_p);
% Cramr-Rao bound for the coupled complex CP decompositions under additive
% complex circular Gaussian noise.
%
% The inputs are:
% 
% - CRB_C,...   : Cramr-Rao bounds for the uncoupled models.
% - D_C_AB,...  : Fisher information blocks for the uncoupled models.
%
% The outputs are:
% 
% - CRB_C_c,... : Cramr-Rao bounds for the coupled models.
% - K_C,...     : Covariance reduction due to coupling function.
%
% List of updates                 -     18/02/2012  -     R. C. Farias and
%                                                         C. Ren
%                                       Creation of the file 
%-------------------------------------------------------------------------%

%---------------------CRB and covariance reductions-----------------------%
% Intrinsic parameter CRB
CRB_g     =     CRB_C+CRB_C_p;
% Covariance reduction on the coupled factors C and C_p
K_C       =     CRB_C*(CRB_g\CRB_C);
K_C_p     =     CRB_C_p*(CRB_g\CRB_C_p);
% Covariance reduction on the uncoupled factors (A, B) and (A_p, B_p)
D_prod    =     D_AB\transpose(D_C_AB);
K_AB      =     D_prod*K_C*transpose(D_prod);
D_prod    =     D_AB_p\transpose(D_C_AB_p);
K_AB_p    =     D_prod*K_C_p*transpose(D_prod);
% Cramr-Rao bounds for the coupled models
% Coupled factors
CRB_C_c   =     CRB_C-K_C;
CRB_C_p_c =     CRB_C_p-K_C_p;
% Uncoupled factors
CRB_AB_c  =     CRB_AB-K_AB;
CRB_AB_p_c=     CRB_AB_p-K_AB_p;
%-------------------------------------------------------------------------%
end